@@ -10,6 +10,7 @@ import os
 import requests
 import json
 import csv
+import pandas as pd
 import PyPDF2
 import re
 import codecs
@@ -27,7 +28,7 @@ from binaryornot.check import is_binary
 
 import pkg_resources
 
-from knps.settings import (
+from settings import (
     CACHE_FILE_PROCESSING,
     KNPS_SERVER_DEV,
     KNPS_SERVER_PROD
@@ -46,13 +47,13 @@ PROCESS_SYNC_AGE_SECONDS = 10
 ###################################################
 def get_version(file_loc = __file__):
     cwdir = os.path.dirname(os.path.realpath(file_loc))
-
-    proj_ver = subprocess.run(["git", "describe", "--tags", "--long"], stdout=subprocess.PIPE, stderr=subprocess.DEVNULL, text=True, cwd=cwdir).stdout.strip()
-    if proj_ver:
-        rev_count = subprocess.run(["git", "log", "--oneline"], stdout=subprocess.PIPE, stderr=subprocess.DEVNULL, text=True, cwd=cwdir).stdout.strip()
+    print(cwdir)
+    try:
+        proj_ver = subprocess.run(["git", "describe", "--tags", "--long"], stdout=subprocess.PIPE, text=True, cwd=cwdir).stdout.strip()
+        rev_count = subprocess.run(["git", "log", "--oneline"], stdout=subprocess.PIPE, text=True, cwd=cwdir).stdout.strip()
         rev_count = len(rev_count.split("\n"))
         return f'{proj_ver}-{rev_count}-development'
-    else:
+    except:
         proj_ver = pkg_resources.require('knps-cli')[0].version
         return f'v{proj_ver}-release'
 
@@ -117,26 +118,28 @@ def getShinglesFname(fname, file_type):
     return getShingles(text, fname, file_type)
 
 def hash_csv_file_lines(fname):
+    data = pd.read_csv(fname)
     hashes = []
-    with open(fname, "rt") as f:
-        i = 0
-        next_read = 0
-        for line in f:
-            if i == next_read:
-                hashes.append(hashlib.md5(line.strip().encode()).hexdigest())
-
-                if i < 100:
-                    next_read += 1
-                elif i < 1000:
-                    next_read += 5
-                elif i < 10000:
-                    next_read += 50
-                elif i < 100000:
-                    next_read += 500
-                else:
-                    next_read += 1000
-
-            i += 1
+    for i in range(100):
+        if i >= data.shape[0]:
+            return hashes;
+        row = data.iloc[i]
+        hashes.append(hashlib.md5(row.__str__().strip().encode()).hexdigest())
+    for i in range(100, 1000, 5):
+        if i >= data.shape[0]:
+            return hashes;
+        row = data.iloc[i:(i+10)]
+        hashes.append(hashlib.md5(row.__str__().strip().encode()).hexdigest())
+    for i in range(1000, 10000, 50):
+        if i >= data.shape[0]:
+            return hashes;
+        row = data.iloc[i:(i+100)]
+        hashes.append(hashlib.md5(row.__str__().strip().encode()).hexdigest())
+    diff = data.shape[0] - 10000
+    jump = diff//100
+    for i in range(10000, data.shape[0], jump):
+        row = data.iloc[i:(i+jump)]
+        hashes.append(hashlib.md5(row.__str__().strip().encode()).hexdigest())
 
     return hashes
 
@@ -268,20 +271,10 @@ def send_createdataset(user, id, title, desc, targetHash):
 
 def hash_CSV_columns(fname):
     hashes = []
-    cols = []
-    with open(fname, "rt") as f:
-        dialect = csv.Sniffer().sniff(f.read(1024))
-        csvfile.seek(0)
-        reader = csv.reader(f, dialect)
-        for row in reader:
-            for i, x in enumerate(row):
-                if len(cols) <= i:
-                    cols.append([])
-                cols[i].append(x)
-
-    for column in cols:
-        column_str = ''.join(column).strip().encode()
-        hashes.append(hashlib.md5(column_str).hexdigest())
+    df = pd.read_csv(fname)
+    for column_name in df.columns:
+        column = df[column_name].__str__().strip().encode()
+        hashes.append(hashlib.md5(column).hexdigest())
     return hashes
 
 def hash_image(fname):
@@ -289,27 +282,28 @@ def hash_image(fname):
     return None
 
 def get_csv_file_shingles(fname, fingerprint_bytes):
+    data = pd.read_csv(fname)
     hashes = []
-    with open(fname, "rt") as f:
-        i = 0
-        next_read = 0
-        for line in f:
-            if i == next_read:
-                hashes.append(int.from_bytes(hashlib.sha256(line.strip().encode()).digest()[:fingerprint_bytes], 'little'))
-
-                if i < 100:
-                    next_read += 1
-                elif i < 1000:
-                    next_read += 5
-                elif i < 10000:
-                    next_read += 50
-                elif i < 100000:
-                    next_read += 500
-                else:
-                    next_read += 1000
-
-            i += 1
-
+    for i in range(100):
+        if i >= data.shape[0]:
+            return hashes;
+        row = data.iloc[i]
+        hashes.append(int.from_bytes(hashlib.sha256(row.__str__().encode()).digest()[:fingerprint_bytes], 'little'))
+    for i in range(100, 1000, 5):
+        if i >= data.shape[0]:
+            return hashes;
+        row = data.iloc[i:(i+10)]
+        hashes.append(int.from_bytes(hashlib.sha256(row.__str__().encode()).digest()[:fingerprint_bytes], 'little'))
+    for i in range(1000, 10000, 50):
+        if i >= data.shape[0]:
+            return hashes;
+        row = data.iloc[i:(i+100)]
+        hashes.append(int.from_bytes(hashlib.sha256(row.__str__().encode()).digest()[:fingerprint_bytes], 'little'))
+    diff = data.shape[0] - 10000
+    jump = diff//100
+    for i in range(10000, data.shape[0], jump):
+        row = data.iloc[i:(i+jump)]
+        hashes.append(int.from_bytes(hashlib.sha256(row.__str__().encode()).digest()[:fingerprint_bytes], 'little'))
     return hashes
 
 # This fucntion removes punctiation and whitespace.
@@ -665,10 +659,11 @@ class Watcher:
 
             file_list = self.user.get_files()
 
-            if process and len(process['output_files']) + len(process['access_files']) > 0:
-                process_files = set.union(process['input_files'], process['output_files'], process['access_files'])
+            if process and len(process['outputs']) + len(process['accesses']) > 0:
+                process_files = set.union(process['inputs'], process['outputs'], process['accesses'])
                 file_list = [value for value in process_files if value in file_list]
 
+
             longTodoList = [x for x in file_list]
             smallTodoLists = [longTodoList[i:i+k] for i in range(0, len(longTodoList), k)]
 
@@ -730,9 +725,9 @@ class Watcher:
             install_id = self.user.get_install_id()
             hostname = socket.gethostname()
 
-            process['input_files'] = [(x, file_hashes[x]) for x in process['input_files'] if x in file_hashes]
-            process['output_files'] = [(x, file_hashes[x]) for x in process['output_files'] if x in file_hashes]
-            process['access_files'] = [(x, file_hashes[x]) for x in process['access_files'] if x in file_hashes]
+            process['input_files'] = [(x, file_hashes[x]) for x in process['inputs'] if x in file_hashes]
+            process['output_files'] = [(x, file_hashes[x]) for x in process['outputs'] if x in file_hashes]
+            process['access_files'] = [(x, file_hashes[x]) for x in process['accesses'] if x in file_hashes]
             process['username'] = self.user.username
             process['knps_version'] = knps_version
             process['install_id'] = install_id
@@ -836,7 +831,6 @@ class Monitor:
                     if diff.seconds >= PROCESS_SYNC_AGE_SECONDS:
                         print(f'Syncing {p["name"]}')
                         procs[key]['synced'] = True
-
                         self.watcher.observeAndSync(process=p)
 
 
@@ -890,9 +884,6 @@ class Monitor:
                                         'inputs': set([]),
                                         'outputs': set([]),
                                         'accesses': set([]),
-                                        'input_files': set([]),
-                                        'output_files': set([]),
-                                        'access_files': set([]),
                                         'cmdline': [],
                                         'pid': '',
                                         'file_data': {}}
@@ -926,17 +917,14 @@ class Monitor:
 
                 if ('WrData' in action or open_type == 'write' or (modified_flag and not ('RdData' in action or open_type == 'read'))):
                     procs[proc_key]['outputs'].add(file_hash)
-                    procs[proc_key]['output_files'].add(file_data['file_name'])
                     procs[proc_key]['last_update'] = dt
                     procs[proc_key].pop('synced', None) # Need to sync again
                 elif ('RdData' in action or open_type == 'read' or not modified_flag):
                     procs[proc_key]['inputs'].add(file_hash)
-                    procs[proc_key]['input_files'].add(file_data['file_name'])
                     procs[proc_key]['last_update'] = dt
                     procs[proc_key].pop('synced', None) # Need to sync again
                 elif pathname not in procs[proc_key]['accesses'] and file_hash not in procs[proc_key]['inputs'] and file_hash not in procs[proc_key]['outputs']:
                     procs[proc_key]['accesses'].add(file_hash)
-                    procs[proc_key]['access_files'].add(file_data['file_name'])
                     procs[proc_key]['last_update'] = dt
                     procs[proc_key].pop('synced', None) # Need to sync again
 
